Crate create3
create3
0.1.0
All Items
Crate Items
Functions
Crate
create3
Functions

calc_
addr
Calculates the address of a contract based on the given deployer and salt.
generate_
salt
Generates a random salt for a given deployer and prefix.
generate_
salt_
suffix
Generates a salt suffix for a given prefix and salt.