pub fn generate_salt_suffix(
deployer: &[u8],
salt_suffix: &str,
prefix: &str,
) -> [u8; 32]Expand description
Generates a salt suffix for a given prefix and salt.
Arguments
deployer- A byte slice representing the create3 deployer address.salt_suffix- A string representing the suffix to append to the generated salt.prefix- A string representing the prefix that the resulting address should start with (without 0x).
Panics
This method will panic if the prefix is greater than 20 bytes in hexadecimal format.
Returns
A 32-byte array representing the generated salt.